@@ -1,5 +1,7 @@
+from functools import cache
 import multiprocessing
 import sys
+from tqdm import tqdm
 from asyncio import wait
 from concurrent.futures import ProcessPoolExecutor, ThreadPoolExecutor, Future, wait, FIRST_EXCEPTION
 from typing import Dict, List
@@ -69,11 +71,16 @@ class DownloadHelper:
                 self._futures.append(self._executor.submit(CloudClient.file_download_handler, value))
 
     def wait(self) -> None:
-        done, not_done = wait(self._futures, return_when=FIRST_EXCEPTION)
-        for future in not_done:
-            future.cancel()
-        for future in done:
-            future.result()
+        # done, not_done = wait(self._futures, return_when=FIRST_EXCEPTION)
+        # for future in not_done:
+        #     future.cancel()
+        # for future in done:
+        #     future.result()
+        for future in tqdm(self._futures):
+            try:
+                future.result()
+            except Exception as exc:
+                print('downloder generated an exception: %s' % (exc)) 
 
     @staticmethod
     def get_stream_data(x_api: X_API, job: Job):
