@@ -354,7 +354,7 @@ class Dataset(DatasetMeta):
         download_helper = DownloadHelper(self._x_api)
 
         count = 0
-        for obj in tqdm(catalog):
+        for obj in catalog:
             count += 1
             ex = False
             image_path = obj["image_path"] if "image_path" in obj else ""
